SphinxHeaderSpec

Trait SphinxHeaderSpec 

pub trait SphinxHeaderSpec {
    type KeyId: BytesRepresentable + Clone;
    type Pseudonym: Pseudonym;
    type RelayerData: BytesRepresentable;
    type PacketReceiverData: BytesRepresentable;
    type SurbReceiverData: BytesRepresentable;
    type PRG: StreamCipher + StreamCipherSeek + KeyIvInit;
    type UH: UniversalHash + KeyInit;
Show 9 associated constants and 2 methods const MAX_HOPS: NonZeroUsize; const RELAYER_DATA_SIZE: usize = <Self::RelayerData>::SIZE; const SURB_RECEIVER_DATA_SIZE: usize = <Self::SurbReceiverData>::SIZE; const RECEIVER_DATA_SIZE: usize = <Self::PacketReceiverData>::SIZE; const KEY_ID_SIZE: NonZeroUsize = _; const TAG_SIZE: usize = <<Self::UH as crypto_traits::BlockSizeUser>::BlockSize>::USIZE; const ROUTING_INFO_LEN: usize = _; const HEADER_LEN: usize = _; const EXT_HEADER_LEN: usize = _; // Provided methods fn generate_filler(secrets: &[SharedSecret]) -> Result<Box<[u8]>> { ... } fn new_prg(secret: &SecretKey) -> Result<Self::PRG> { ... }
}
Contains the necessary size and type specifications for the Sphinx packet header.

Required Associated Constants

const MAX_HOPS: NonZeroUsize

Maximum number of hops.

Provided Associated Constants

const RELAYER_DATA_SIZE: usize = <Self::RelayerData>::SIZE

Size of the additional data for relayers.

const SURB_RECEIVER_DATA_SIZE: usize = <Self::SurbReceiverData>::SIZE

Size of the additional data included in SURBs.

const RECEIVER_DATA_SIZE: usize = <Self::PacketReceiverData>::SIZE

Size of the additional data for the packet receiver.

const KEY_ID_SIZE: NonZeroUsize = _

Size of the public key identifier

const TAG_SIZE: usize = <<Self::UH as crypto_traits::BlockSizeUser>::BlockSize>::USIZE

Size of the one-time authenticator tag.

const ROUTING_INFO_LEN: usize = _

Length of the header routing information per hop.

The value shall not be overridden.

const HEADER_LEN: usize = _

Length of the whole Sphinx header.

The value shall not be overridden.

const EXT_HEADER_LEN: usize = _

Extended header size used for computations.

The value shall not be overridden.

Required Associated Types

type KeyId: BytesRepresentable + Clone

Public key identifier type.

type Pseudonym: Pseudonym

Pseudonym used to represent node for SURBs.

type RelayerData: BytesRepresentable

Type representing additional data for relayers.

type PacketReceiverData: BytesRepresentable

Type representing additional data delivered to the packet receiver.

It is delivered on both forward and return paths.

type SurbReceiverData: BytesRepresentable

Type representing additional data delivered with each SURB to the packet receiver.

It is delivered only on the forward path.

type PRG: StreamCipher + StreamCipherSeek + KeyIvInit

Pseudo-Random Generator function used to encrypt and decrypt the Sphinx header.

type UH: UniversalHash + KeyInit

One-time authenticator used for Sphinx header tag.

Provided Methods

fn generate_filler(secrets: &[SharedSecret]) -> Result<Box<[u8]>>

fn new_prg(secret: &SecretKey) -> Result<Self::PRG>

Instantiates a new Pseudo-Random Generator.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl SphinxHeaderSpec for HoprSphinxHeaderSpec

Source

const MAX_HOPS: NonZeroUsize

Source

type KeyId = KeyIdent

Source

type PRG = StreamCipherCoreWrapper<ChaChaCore<UInt<UInt<UInt<UInt<UTerm, B1>, B0>, B1>, B0>>>

Source

type PacketReceiverData = HoprSenderId

Source

type Pseudonym = SimplePseudonym

Source

type RelayerData = ProofOfRelayString

Source

type SurbReceiverData = SurbReceiverInfo

Source

type UH = Poly1305